@@ -7,7 +7,7 @@ use DateTime::Format::Pg;
 use Rose::DB;
 our @ISA = qw(Rose::DB);
 
-our $VERSION = '0.57';
+our $VERSION = '0.58';
 
 our $Debug = 0;
 
@@ -250,7 +250,7 @@ sub refine_dbi_column_info
          $col_info->{'TYPE_NAME'} eq 'bigint')
       {
         my $db = $meta->db;
-#$DB::single = 1;
+
         my $auto_seq =
           $db->auto_sequence_name(table  => $meta->table,
                                   column => $col_info->{'COLUMN_NAME'});
@@ -328,19 +328,19 @@ sub parse_dbi_column_info_default
 
     my $pg_vers = $self->dbh->{'pg_server_version'};
 
-    # Example: q('value'::character varying)
-    if(/^'.+'::[\w ]+$/)
+    # Example: 'value'::character varying
+    # Example: ('now'::text)::timestamp(0)
+    if(/^\(*'(.+)'::.+$/)
     {
-      my $default;
+      my $default = $1;
 
       # Single quotes are backslash-escaped, but Postgres 8.1 and
       # later uses doubled quotes '' instead.
-      if($pg_vers >= 80100 && /^'((?:[^']+|'')*)'::[\w ]+$/)
+      if($pg_vers >= 80100 && index($default, q('')) > 0)
       {
-        $default = $1;
         $default =~ s/''/'/g;
       }
-      elsif($pg_vers < 80100 && /^'((?:[^\\']+|\\.)*)'::[\w ]+$/)
+      elsif($pg_vers < 80100 && index($default, q(\')) > 0)
       {
         $default = $1;
         $default =~ s/\\'/'/g;
